@@ -24,6 +24,7 @@ from gcp_airflow_foundations.operators.gcp.create_dataset import CustomBigQueryC
 def ods_builder(
     project_id: str,
     table_id: str,
+    dag_table_id: str,
     dataset_id: str,
     landing_zone_dataset: str,
     landing_zone_table_name_override: Optional[str],
@@ -81,6 +82,7 @@ def ods_builder(
         project_id=project_id,
         dataset_id=dataset_id,
         table_id=table_id,
+        dag_table_id=dag_table_id,
         cluster_fields=cluster_fields,
         time_partitioning=time_partitioning,
         task_group=taskgroup,
@@ -92,6 +94,7 @@ def ods_builder(
         task_id="schema_migration",
         project_id=project_id,
         table_id=table_id,
+        dag_table_id=dag_table_id,
         dataset_id=dataset_id,
         task_group=taskgroup,
         dag=dag
@@ -105,6 +108,7 @@ def ods_builder(
         data_dataset_name=dataset_id,
         stg_table_name=landing_zone_table_name_override,
         data_table_name=table_id,
+        dag_table_id=dag_table_id,
         surrogate_keys=surrogate_keys,
         column_mapping=column_mapping,
         column_casting=column_casting,
