@@ -1,14 +1,17 @@
 from abc import ABC, abstractmethod, abstractproperty
 
 from airflow.models.dag import DAG
+from airflow.utils.task_group import TaskGroup
 
 from gcp_airflow_foundations.base_class.data_source_table_config import (
     DataSourceTablesConfig,
 )
 from gcp_airflow_foundations.base_class.source_table_config import SourceTableConfig
+from gcp_airflow_foundations.base_class.source_template_config import SourceTemplateConfig
 from gcp_airflow_foundations.base_class.source_config import SourceConfig
 from gcp_airflow_foundations.enums.schema_source_type import SchemaSourceType
 from gcp_airflow_foundations.common.gcp.load_builder import load_builder
+from gcp_airflow_foundations.common.utils.convert_config import convert_template_to_table
 from gcp_airflow_foundations.source_class.schema_source_config import (
     AutoSchemaSourceConfig,
     GCSSchemaSourceConfig,
@@ -16,6 +19,7 @@ from gcp_airflow_foundations.source_class.schema_source_config import (
 )
 
 import logging
+import re
 
 
 class DagBuilder(ABC):
@@ -55,35 +59,26 @@ class DagBuilder(ABC):
 
         dags = []
         for table_config in self.config.tables:
-            table_default_task_args = self.default_task_args_for_table(
-                self.config, table_config
-            )
-            logging.info(f"table_default_task_args {table_default_task_args}")
+            dag = self.create_dag(table_config)
+            dags.append(dag)
 
-            kwargs = data_source.dag_args if data_source.dag_args else {}
-
-            with DAG(
-                dag_id=f"{data_source.name}.{table_config.table_name}",
-                description=f"{data_source.name} to BigQuery load for {table_config.table_name}",
-                schedule_interval=data_source.ingest_schedule,
-                default_args=table_default_task_args,
-                catchup=data_source.catchup,
-                render_template_as_native_obj=True,
-                **kwargs,
-            ) as dag:
-
-                load_to_bq_landing = self.get_bq_ingestion_task(dag, table_config)
-
-                self.get_datastore_ingestion_task(
-                    dag, load_to_bq_landing, data_source, table_config
-                )
+        # loop through templates
+        for template_config in self.config.templates:
+            table_list = self.get_templated_table_list(template_config.template_ingestion_options)
 
+            if template_config.template_ingestion_options.dag_creation_mode == "TABLE":
+                for table in table_list:
+                    table_config = convert_template_to_table(template_config, table)
+                    dag = self.create_dag(table_config)
+                    dags.append(dag)
+            else:
+                dag = self.create_dag_source_level(template_config, table_list)
                 dags.append(dag)
 
-        extra_dags=  self.get_extra_dags()
+        extra_dags = self.get_extra_dags()
         if extra_dags is not None and not extra_dags == []:
             dags = dags + self.get_extra_dags()
-            
+
         return dags
 
     @abstractmethod
@@ -141,4 +136,78 @@ class DagBuilder(ABC):
         return {
             **self.default_task_args,
             "start_date": config.table_start_date(table_config),
-        }
\ No newline at end of file
+        }
+
+    def create_dag(self, table_config: SourceTableConfig):
+        data_source = self.config.source
+        table_default_task_args = self.default_task_args_for_table(
+            self.config, table_config
+        )
+
+        logging.info(f"table_default_task_args {table_default_task_args}")
+
+        kwargs = data_source.dag_args if data_source.dag_args else {}
+
+        with DAG(
+            dag_id=f"{data_source.name}.{table_config.table_name}",
+            description=f"{data_source.name} to BigQuery load for {table_config.table_name}",
+            schedule_interval=data_source.ingest_schedule,
+            default_args=table_default_task_args,
+            catchup=data_source.catchup,
+            render_template_as_native_obj=True,
+            **kwargs,
+        ) as dag:
+
+            with TaskGroup(group_id=table_config.table_name) as table_task_group:
+                self.create_dag_tasks(dag, data_source, table_config)
+            table_task_group
+            return dag
+
+    def create_dag_source_level(self, template_config: SourceTemplateConfig, table_names):
+        data_source = self.config.source
+        table_default_task_args = self.default_task_args_for_table(
+            self.config, template_config
+        )
+        logging.info(f"table_default_task_args {table_default_task_args}")
+
+        kwargs = data_source.dag_args if data_source.dag_args else {}
+
+        with DAG(
+            dag_id=f"{data_source.name}.{template_config.template_ingestion_options.ingestion_name}",
+            description=f"{data_source.name} to BigQuery load for {template_config.template_ingestion_options.ingestion_name}",
+            schedule_interval=data_source.ingest_schedule,
+            default_args=table_default_task_args,
+            catchup=data_source.catchup,
+            render_template_as_native_obj=True,
+            **kwargs,
+        ) as dag:
+
+            for i in range(len(table_names)):
+                table_config = convert_template_to_table(template_config, table_names[i], i)
+                with TaskGroup(group_id=table_names[i]) as table_task_group:
+                    self.create_dag_tasks(dag, data_source, table_config)
+                table_task_group
+
+            return dag
+
+    def create_dag_tasks(self, dag, data_source, table_config):
+        load_to_bq_landing = self.get_bq_ingestion_task(dag, table_config)
+        self.get_datastore_ingestion_task(
+            dag, load_to_bq_landing, data_source, table_config
+        )
+
+    def get_templated_table_list(self, templated_ingestion_options):
+        if templated_ingestion_options.ingest_mode.value == "INGEST_BY_TABLE_NAMES":
+            return templated_ingestion_options.table_names
+
+        full_table_list = self.get_source_tables_to_ingest()
+
+        if templated_ingestion_options.ingest_mode.value == "INGEST_ALL":
+            return full_table_list
+
+        regex_pattern = templated_ingestion_options.regex_pattern
+        r = re.compile(regex_pattern)
+        return list(filter(r.match, full_table_list))
+
+    def get_source_tables_to_ingest(self):
+        return []
